(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     28674,        698]
NotebookOptionsPosition[     25930,        652]
NotebookOutlinePosition[     26505,        673]
CellTagsIndexPosition[     26462,        670]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 20 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"197c79a1-2c6c-4e31-b35f-1e72ce723773"],

Cell["Chapter 8, Section 8.17, Figure 8.30", "Section",ExpressionUUID->"e6b3d84d-6759-46a0-880f-7bf2301a39fd"],

Cell["\<\
We start by inputting the orbital radii of Io, Europa and Ganymede in units \
of the planetary radius.  The data are taken from \
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"00c0a256-dcce-4fa9-9397-05eafe820684"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"r1", "=", 
   RowBox[{"421600.", "/", "71398."}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"r2", "=", 
   RowBox[{"670900.", "/", "71398."}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"r3", "=", 
   RowBox[{"1070000.", "/", "71398."}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.882018153976308*^9, 3.8820181539902687`*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"989cec23-e32e-43ec-a933-bae65b6ae38f"],

Cell["Set up the two ratios of mean motions.", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"223c9349-5b80-49f2-b805-33ef7d808d53"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"n12", "=", "0.5"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"n23", "=", 
   RowBox[{"n12", "/", "2"}]}], ";"}]}], "Input",
 CellChangeTimes->{{3.882018169477786*^9, 3.8820181694891644`*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"3d4bd3d9-5c9c-42f5-83c2-dfe00f13651d"],

Cell["\<\
Define functions to calculate the position vector of each satellite as a \
function of time.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"fc8983eb-2924-43e3-bbc8-95341fe838e5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"pos1", "[", "t_", "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"x", "=", 
     RowBox[{"r1", "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"t", "+", "Pi"}], "]"}]}]}], ";", " ", 
    RowBox[{"y", "=", 
     RowBox[{"r1", "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"t", "+", "Pi"}], "]"}]}]}], ";", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], ")"}]}], "\n", 
 RowBox[{
  RowBox[{"pos2", "[", "t_", "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"x", "=", 
     RowBox[{"r2", "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"n12", "*", "t"}], "]"}]}]}], ";", " ", 
    RowBox[{"y", "=", 
     RowBox[{"r2", "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"n12", "*", "t"}], "]"}]}]}], ";", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], ")"}]}], "\n", 
 RowBox[{
  RowBox[{"pos3", "[", "t_", "]"}], ":=", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"x", "=", 
     RowBox[{"r3", "*", 
      RowBox[{"Cos", "[", 
       RowBox[{"n23", "*", "t"}], "]"}]}]}], ";", " ", 
    RowBox[{"y", "=", 
     RowBox[{"r3", "*", 
      RowBox[{"Sin", "[", 
       RowBox[{"n23", "*", "t"}], "]"}]}]}], ";", " ", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}]}], ")"}]}]}], "Input",
 CellChangeTimes->{{3.8820181813253517`*^9, 3.882018181336488*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"41650e0b-7b0a-405e-aa10-02f006613a1d"],

Cell[TextData[{
 "Define a ",
 StyleBox["Circle", "Input"],
 " for the orbital path of each satellite ..."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f66fec3f-3be1-4054-87be-17d1b5ced9d6"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"orb1", "=", 
   RowBox[{"{", 
    RowBox[{"Red", ",", 
     RowBox[{"Circle", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", "r1"}], "]"}]}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"orb2", "=", 
   RowBox[{"{", 
    RowBox[{"Blue", ",", 
     RowBox[{"Circle", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", "r2"}], "]"}]}], "}"}]}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"orb3", "=", 
   RowBox[{"{", 
    RowBox[{"Purple", ",", 
     RowBox[{"Circle", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", "r3"}], "]"}]}], "}"}]}], 
  ";"}]}], "Input",
 CellChangeTimes->{{3.882018193816691*^9, 3.8820181938285007`*^9}, {
  3.882080740597886*^9, 3.882080744844186*^9}, {3.882080776860969*^9, 
  3.882080792315476*^9}, {3.8822572195337067`*^9, 3.8822572212201223`*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"029bc119-5715-4528-bb90-3121b9e77f7e"],

Cell[".. and the planet Jupiter (with unit radius).", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"d2151104-13ef-43d2-9e25-51924d59c176"],

Cell[BoxData[
 RowBox[{
  RowBox[{"jup", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Circle", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}], ",", "2"}], "]"}], ",", 
     RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
     RowBox[{"FontSize", "\[Rule]", "14"}], ",", 
     RowBox[{"Text", "[", 
      RowBox[{"\"\<J\>\"", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         RowBox[{"-", "0.5"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0"}], "}"}]}], "]"}]}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.882018204952558*^9, 3.88201820496421*^9}, {
  3.882018396000485*^9, 3.882018454423924*^9}, {3.8820184953594313`*^9, 
  3.88201850894864*^9}, {3.882018542436408*^9, 3.88201854752909*^9}, {
  3.882018582986476*^9, 3.882018583184904*^9}, {3.8820186147079144`*^9, 
  3.882018682008917*^9}, {3.882018715586124*^9, 3.882018765040577*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"6e71674d-fe11-4c68-90e9-46d5d7d0db1f"],

Cell["Define the labels for each plot.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.882088995403121*^9, 3.8820890024277287`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"aa3e97ca-a22d-46a9-b245-6e33ee8f3de7"],

Cell[BoxData[
 RowBox[{
  RowBox[{"labels", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<(a)\>\"", ",", "\"\<(b)\>\"", ",", "\"\<(c)\>\"", ",", "\"\<(d)\>\"",
      ",", "\"\<(e)\>\"", ",", "\"\<(f)\>\""}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8820874990493526`*^9, 3.882087559646365*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"3f8529aa-acdd-4c70-9eda-1f148d89993e"],

Cell[TextData[{
 "Define a function ",
 StyleBox["Satellites", "Input"],
 " to do all the plots together for a particular time."
}], "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ca363aea-bf2b-459c-b6a7-de0925e34b15"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Satellites", "[", "t_", "]"}], " ", ":=", "\n", 
  RowBox[{"Show", "[", "\[IndentingNewLine]", 
   RowBox[{"Graphics", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "jup", ",", "orb1", ",", " ", "orb2", ",", "orb3", ",", 
       "\[IndentingNewLine]", 
       RowBox[{"AbsolutePointSize", "[", "7", "]"}], ",", 
       RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
       RowBox[{"FontSize", "\[Rule]", "12"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Disk", "[", 
        RowBox[{
         RowBox[{"pos1", "[", "t", "]"}], ",", "1"}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<I\>\"", ",", 
         RowBox[{"0.57", "*", 
          RowBox[{"pos1", "[", "t", "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Disk", "[", 
        RowBox[{
         RowBox[{"pos2", "[", "t", "]"}], ",", "1"}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<E\>\"", ",", 
         RowBox[{"1.25", "*", 
          RowBox[{"pos2", "[", "t", "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Disk", "[", 
        RowBox[{
         RowBox[{"pos3", "[", "t", "]"}], ",", "1"}], "]"}], ",", 
       RowBox[{"Text", "[", 
        RowBox[{"\"\<G\>\"", ",", 
         RowBox[{"1.19", "*", 
          RowBox[{"pos3", "[", "t", "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"0", ",", "0"}], "}"}]}], "]"}]}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{"AspectRatio", "->", "1"}], ",", 
     RowBox[{"PlotRange", "->", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "20"}], ",", "20"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "20"}], ",", "20"}], "}"}]}], "}"}]}]}], "]"}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.882018218741391*^9, 3.882018278506495*^9}, {
  3.8820796060024357`*^9, 3.882079627036824*^9}, {3.882079734555588*^9, 
  3.8820797699878387`*^9}, {3.882079875932444*^9, 3.882079888299057*^9}, {
  3.8820799579878817`*^9, 3.882079971252018*^9}, {3.882080057147665*^9, 
  3.8820800578511353`*^9}, {3.88208010422113*^9, 3.8820801936891727`*^9}, {
  3.88208027602932*^9, 3.882080385322434*^9}, {3.8820804205635033`*^9, 
  3.882080428010343*^9}, {3.882080482610573*^9, 3.882080590286769*^9}, {
  3.882086393889784*^9, 3.882086403104228*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"7b2b514b-554f-4016-93dd-9a8c101b360b"],

Cell["\<\
Define the specific times we are interested in.  These times give the whole \
sequence of conjunctions between pairs of satellites.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f40ca323-7c2b-4c33-a90f-5a91b9b1a46e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"time", " ", "=", " ", 
  RowBox[{"{", 
   RowBox[{"0", ",", " ", 
    RowBox[{"4", "*", 
     RowBox[{"Pi", "/", "3"}]}], ",", " ", 
    RowBox[{"2", "Pi"}], ",", " ", 
    RowBox[{"4", "Pi"}], ",", " ", 
    RowBox[{"6", "Pi"}], ",", " ", 
    RowBox[{
     RowBox[{"6", "Pi"}], "+", 
     RowBox[{"2", 
      RowBox[{"Pi", "/", "3"}]}]}]}], "}"}]}]], "Input",
 CellChangeTimes->{{3.882018296997086*^9, 3.882018297008494*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"5dfece40-daed-40f0-878b-130253526cc9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox[
    RowBox[{"4", " ", "\[Pi]"}], "3"], ",", 
   RowBox[{"2", " ", "\[Pi]"}], ",", 
   RowBox[{"4", " ", "\[Pi]"}], ",", 
   RowBox[{"6", " ", "\[Pi]"}], ",", 
   FractionBox[
    RowBox[{"20", " ", "\[Pi]"}], "3"]}], "}"}]], "Output",
 CellChangeTimes->{3.88201829771038*^9, 3.8820796081077213`*^9, 
  3.8820858000540943`*^9, 3.882088560685732*^9, 3.882088891429031*^9, 
  3.882257235117968*^9, 3.890980827312353*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"85465226-cb22-406a-b3a0-2d49e3b28fc6"]
}, Open  ]],

Cell["\<\
Plot the orbital positions at each time, putting each plot in an array \
element.\
\>", "Text",
 CellFrame->True,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9b8c70d7-bdcb-41e7-acfa-4530768fafbf"],

Cell[BoxData[
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"plot", "[", "i", "]"}], "=", "\[IndentingNewLine]", 
    RowBox[{"Show", "[", 
     RowBox[{
      RowBox[{"Satellites", "[", 
       RowBox[{"time", "[", 
        RowBox[{"[", "i", "]"}], "]"}], "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"Graphics", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
         RowBox[{"FontSize", "\[Rule]", "16"}], ",", 
         RowBox[{"Text", "[", 
          RowBox[{
           RowBox[{"labels", "[", 
            RowBox[{"[", "i", "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "16"}], ",", "16"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"-", "1"}], ",", "0"}], "}"}]}], "]"}]}], "}"}], "]"}]}],
      "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"{", 
    RowBox[{"i", ",", "6"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.882018309764456*^9, 3.8820183097754517`*^9}, {
  3.882087623575801*^9, 3.882087708661705*^9}, {3.8820877623491592`*^9, 
  3.8820879115460052`*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"aede34f6-e2e7-4de8-9b78-23e915becc21"],

Cell["\<\
Display all six plots together.  This is Fig.8.30.

Note that when two of the satellites have a conjunction, the third satellite \
is at least 60\[Degree] away in longitude.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.8820187825949717`*^9, 3.882018803417101*^9}, {
  3.8820879930169373`*^9, 3.8820880512626038`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"f51beef0-218a-413d-913e-90855c974add"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Show", "[", "\[IndentingNewLine]", 
  RowBox[{"GraphicsGrid", "[", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"plot", "[", "1", "]"}], ",", 
       RowBox[{"plot", "[", "2", "]"}], ",", 
       RowBox[{"plot", "[", "3", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"plot", "[", "4", "]"}], ",", 
       RowBox[{"plot", "[", "5", "]"}], ",", 
       RowBox[{"plot", "[", "6", "]"}]}], "}"}]}], "}"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.882018323227662*^9, 3.882018348591963*^9}, {
   3.882079649924423*^9, 3.882079669530654*^9}, 3.8820869014962397`*^9},
 CellLabel->"In[17]:=",ExpressionUUID->"cb2cd810-19ad-4a5e-b5b6-852a00b337f5"],

Cell[BoxData[
 GraphicsBox[{{}, {{InsetBox[
      GraphicsBox[{{{CircleBox[{0, 0}, 2], 
          
          StyleBox[
           InsetBox["\<\"J\"\>", {0, -0.5}, NCache[
            ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
             ImageScaled[{0.5, 0.5}]]],
           FontFamily->"Times",
           FontSize->14]}, 
         {RGBColor[1, 0, 0], CircleBox[{0, 0}, 5.904927308888204]}, 
         {RGBColor[0, 0, 1], CircleBox[{0, 0}, 9.39662175411076]}, 
         {RGBColor[0.5, 0, 0.5], CircleBox[{0, 0}, 14.986414185271295]}, 
         {AbsolutePointSize[7], 
          
          StyleBox[{DiskBox[{-5.904927308888204, 0.}, 1], 
            InsetBox["\<\"I\"\>", {-3.365808566066276, 0.}, NCache[
             ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]], DiskBox[{9.39662175411076, 0.}, 1], 
            InsetBox["\<\"E\"\>", {11.74577719263845, 0.}, NCache[
             ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]], DiskBox[{14.986414185271295, 0.}, 1],
             InsetBox["\<\"G\"\>", {17.83383288047284, 0.}, NCache[
             ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]]},
           FontFamily->"Times",
           FontSize->12]}}, 
        StyleBox[
         InsetBox["\<\"(a)\"\>", {-16, 16}, NCache[
          ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]],
         FontFamily->"Times",
         FontSize->16]},
       AspectRatio->1,
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       PlotRange->{{-20, 20}, {-20, 20}}], {193.5, -192.}, 
      ImageScaled[{0.5, 0.5}], {360., 360.},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
     InsetBox[
      GraphicsBox[{{{CircleBox[{0, 0}, 2], 
          
          StyleBox[
           InsetBox["\<\"J\"\>", {0, -0.5}, NCache[
            ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
             ImageScaled[{0.5, 0.5}]]],
           FontFamily->"Times",
           FontSize->14]}, 
         {RGBColor[1, 0, 0], CircleBox[{0, 0}, 5.904927308888204]}, 
         {RGBColor[0, 0, 1], CircleBox[{0, 0}, 9.39662175411076]}, 
         {RGBColor[0.5, 0, 0.5], CircleBox[{0, 0}, 14.986414185271295]}, 
         {AbsolutePointSize[7], 
          
          StyleBox[{DiskBox[{2.952463654444102, 5.113817056997665}, 1], 
            InsetBox["\<\"I\"\>", {1.682904283033138, 2.9148757224886688}, 
             NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]], 
            DiskBox[{-4.698310877055378, 8.137713148813413}, 1], 
            InsetBox["\<\"E\"\>", {-5.872888596319222, 10.172141436016766}, 
             NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]], 
            DiskBox[{7.493207092635649, 12.978615396080412}, 1], 
            InsetBox["\<\"G\"\>", {8.916916440236422, 15.44455232133569}, 
             NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]]},
           FontFamily->"Times",
           FontSize->12]}}, 
        StyleBox[
         InsetBox["\<\"(b)\"\>", {-16, 16}, NCache[
          ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]],
         FontFamily->"Times",
         FontSize->16]},
       AspectRatio->1,
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       PlotRange->{{-20, 20}, {-20, 20}}], {580.5, -192.}, 
      ImageScaled[{0.5, 0.5}], {360., 360.},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
     InsetBox[
      GraphicsBox[{{{CircleBox[{0, 0}, 2], 
          
          StyleBox[
           InsetBox["\<\"J\"\>", {0, -0.5}, NCache[
            ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
             ImageScaled[{0.5, 0.5}]]],
           FontFamily->"Times",
           FontSize->14]}, 
         {RGBColor[1, 0, 0], CircleBox[{0, 0}, 5.904927308888204]}, 
         {RGBColor[0, 0, 1], CircleBox[{0, 0}, 9.39662175411076]}, 
         {RGBColor[0.5, 0, 0.5], CircleBox[{0, 0}, 14.986414185271295]}, 
         {AbsolutePointSize[7], 
          
          StyleBox[{DiskBox[{-5.904927308888204, 0.}, 1], 
            InsetBox["\<\"I\"\>", {-3.365808566066276, 0.}, NCache[
             ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]], 
            DiskBox[{-9.39662175411076, 1.1507542753970128*^-15}, 1], 
            InsetBox["\<\"E\"\>", {-11.74577719263845, 1.438442844246266*^-15},
              NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]], 
            DiskBox[{9.176532081344491*^-16, 14.986414185271295}, 1], 
            InsetBox["\<\"G\"\>", {1.0920073176799945*^-15, 17.83383288047284},
              NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]]},
           FontFamily->"Times",
           FontSize->12]}}, 
        StyleBox[
         InsetBox["\<\"(c)\"\>", {-16, 16}, NCache[
          ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]],
         FontFamily->"Times",
         FontSize->16]},
       AspectRatio->1,
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       PlotRange->{{-20, 20}, {-20, 20}}], {967.5, -192.}, 
      ImageScaled[{0.5, 0.5}], {360., 360.},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}, {
     InsetBox[
      GraphicsBox[{{{CircleBox[{0, 0}, 2], 
          
          StyleBox[
           InsetBox["\<\"J\"\>", {0, -0.5}, NCache[
            ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
             ImageScaled[{0.5, 0.5}]]],
           FontFamily->"Times",
           FontSize->14]}, 
         {RGBColor[1, 0, 0], CircleBox[{0, 0}, 5.904927308888204]}, 
         {RGBColor[0, 0, 1], CircleBox[{0, 0}, 9.39662175411076]}, 
         {RGBColor[0.5, 0, 0.5], CircleBox[{0, 0}, 14.986414185271295]}, 
         {AbsolutePointSize[7], 
          
          StyleBox[{DiskBox[{-5.904927308888204, 0.}, 1], 
            InsetBox["\<\"I\"\>", {-3.365808566066276, 0.}, NCache[
             ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]], 
            DiskBox[{9.39662175411076, -2.3015085507940256*^-15}, 1], 
            InsetBox["\<\"E\"\>", {11.74577719263845, -2.876885688492532*^-15},
              NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]], 
            DiskBox[{-14.986414185271295, 1.8353064162688982*^-15}, 1], 
            InsetBox["\<\"G\"\>", {-17.83383288047284, 2.184014635359989*^-15},
              NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]]},
           FontFamily->"Times",
           FontSize->12]}}, 
        StyleBox[
         InsetBox["\<\"(d)\"\>", {-16, 16}, NCache[
          ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]],
         FontFamily->"Times",
         FontSize->16]},
       AspectRatio->1,
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       PlotRange->{{-20, 20}, {-20, 20}}], {193.5, -576.}, 
      ImageScaled[{0.5, 0.5}], {360., 360.},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
     InsetBox[
      GraphicsBox[{{{CircleBox[{0, 0}, 2], 
          
          StyleBox[
           InsetBox["\<\"J\"\>", {0, -0.5}, NCache[
            ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
             ImageScaled[{0.5, 0.5}]]],
           FontFamily->"Times",
           FontSize->14]}, 
         {RGBColor[1, 0, 0], CircleBox[{0, 0}, 5.904927308888204]}, 
         {RGBColor[0, 0, 1], CircleBox[{0, 0}, 9.39662175411076]}, 
         {RGBColor[0.5, 0, 0.5], CircleBox[{0, 0}, 14.986414185271295]}, 
         {AbsolutePointSize[7], 
          
          StyleBox[{DiskBox[{-5.904927308888204, 0.}, 1], 
            InsetBox["\<\"I\"\>", {-3.365808566066276, 0.}, NCache[
             ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]], 
            DiskBox[{-9.39662175411076, 3.4522628261910385*^-15}, 1], 
            InsetBox["\<\"E\"\>", {-11.74577719263845, 4.315328532738798*^-15},
              NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]], 
            DiskBox[{-2.7529596244033468*^-15, -14.986414185271295}, 1], 
            InsetBox["\<\"G\"\>", {-3.2760219530399824*^-15, -17.83383288047284},
              NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]]},
           FontFamily->"Times",
           FontSize->12]}}, 
        StyleBox[
         InsetBox["\<\"(e)\"\>", {-16, 16}, NCache[
          ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]],
         FontFamily->"Times",
         FontSize->16]},
       AspectRatio->1,
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       PlotRange->{{-20, 20}, {-20, 20}}], {580.5, -576.}, 
      ImageScaled[{0.5, 0.5}], {360., 360.},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}], 
     InsetBox[
      GraphicsBox[{{{CircleBox[{0, 0}, 2], 
          
          StyleBox[
           InsetBox["\<\"J\"\>", {0, -0.5}, NCache[
            ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
             ImageScaled[{0.5, 0.5}]]],
           FontFamily->"Times",
           FontSize->14]}, 
         {RGBColor[1, 0, 0], CircleBox[{0, 0}, 5.904927308888204]}, 
         {RGBColor[0, 0, 1], CircleBox[{0, 0}, 9.39662175411076]}, 
         {RGBColor[0.5, 0, 0.5], CircleBox[{0, 0}, 14.986414185271295]}, 
         {AbsolutePointSize[7], 
          
          StyleBox[{DiskBox[{2.952463654444102, -5.113817056997665}, 1], 
            InsetBox["\<\"I\"\>", {1.682904283033138, -2.9148757224886688}, 
             NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]], 
            DiskBox[{-4.698310877055378, -8.137713148813411}, 1], 
            InsetBox["\<\"E\"\>", {-5.872888596319222, -10.172141436016764}, 
             NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]], 
            DiskBox[{7.4932070926356475, -12.978615396080412}, 1], 
            InsetBox["\<\"G\"\>", {8.91691644023642, -15.44455232133569}, 
             NCache[ImageScaled[{Rational[1, 2], Rational[1, 2]}], 
              ImageScaled[{0.5, 0.5}]]]},
           FontFamily->"Times",
           FontSize->12]}}, 
        StyleBox[
         InsetBox["\<\"(f)\"\>", {-16, 16}, NCache[
          ImageScaled[{0, Rational[1, 2]}], ImageScaled[{0, 0.5}]]],
         FontFamily->"Times",
         FontSize->16]},
       AspectRatio->1,
       DisplayFunction->Identity,
       ImagePadding->{{0., 0.}, {0., 0.}},
       PlotRange->{{-20, 20}, {-20, 20}}], {967.5, -576.}, 
      ImageScaled[{0.5, 0.5}], {360., 360.},
      BaseStyle->{Graphics3DBoxOptions -> {SphericalRegion -> False}}]}}, {}},
  
  ImageSize->{
    UpTo[600], 
    UpTo[700]},
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{{3.88201834199785*^9, 3.882018350266736*^9}, {
   3.8820184103039713`*^9, 3.8820184290318413`*^9}, {3.882018555621644*^9, 
   3.882018592446419*^9}, {3.8820186315864897`*^9, 3.882018692702456*^9}, 
   3.882018726604513*^9, {3.8820187569978952`*^9, 3.8820187744699697`*^9}, {
   3.8820796085796833`*^9, 3.882079670680464*^9}, 3.882079984917581*^9, 
   3.8820800658034153`*^9, 3.8820801789820137`*^9, 3.882080228631859*^9, 
   3.882080283409389*^9, {3.882080319469288*^9, 3.882080392395516*^9}, 
   3.8820804338450823`*^9, {3.882080499935878*^9, 3.882080596248375*^9}, 
   3.8820807568835783`*^9, 3.8820808029797564`*^9, 3.8820858067134447`*^9, 
   3.882086421429246*^9, 3.882086903888628*^9, 3.882087826564809*^9, {
   3.8820878745033207`*^9, 3.882087883588986*^9}, 3.882087915874497*^9, 
   3.882088561664999*^9, 3.882088891984827*^9, 3.882257235674077*^9, 
   3.8909808275446978`*^9},
 CellLabel->"Out[17]=",ExpressionUUID->"a49055ca-3751-4294-9e58-a488f5d23675"]
}, Open  ]]
},
WindowToolbars->"MultipurposeBar",
CellGrouping->Manual,
WindowSize->{1051, 663},
WindowMargins->{{83, Automatic}, {Automatic, 26}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
ShowCellLabel->True,
ShowCellTags->False,
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"731053b8-8323-4e7d-872c-5b0444f75492"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 439, 9, 53, "Text",ExpressionUUID->"197c79a1-2c6c-4e31-b35f-1e72ce723773"],
Cell[1000, 31, 110, 0, 67, "Section",ExpressionUUID->"e6b3d84d-6759-46a0-880f-7bf2301a39fd"],
Cell[1113, 33, 262, 6, 49, "Text",ExpressionUUID->"00c0a256-dcce-4fa9-9397-05eafe820684"],
Cell[1378, 41, 426, 11, 73, "Input",ExpressionUUID->"989cec23-e32e-43ec-a933-bae65b6ae38f"],
Cell[1807, 54, 164, 3, 53, "Text",ExpressionUUID->"223c9349-5b80-49f2-b805-33ef7d808d53"],
Cell[1974, 59, 298, 7, 52, "Input",ExpressionUUID->"3d4bd3d9-5c9c-42f5-83c2-dfe00f13651d"],
Cell[2275, 68, 226, 6, 53, "Text",ExpressionUUID->"fc8983eb-2924-43e3-bbc8-95341fe838e5"],
Cell[2504, 76, 1410, 44, 73, "Input",ExpressionUUID->"41650e0b-7b0a-405e-aa10-02f006613a1d"],
Cell[3917, 122, 228, 7, 53, "Text",ExpressionUUID->"f66fec3f-3be1-4054-87be-17d1b5ced9d6"],
Cell[4148, 131, 1003, 31, 73, "Input",ExpressionUUID->"029bc119-5715-4528-bb90-3121b9e77f7e"],
Cell[5154, 164, 171, 3, 53, "Text",ExpressionUUID->"d2151104-13ef-43d2-9e25-51924d59c176"],
Cell[5328, 169, 1005, 23, 30, "Input",ExpressionUUID->"6e71674d-fe11-4c68-90e9-46d5d7d0db1f"],
Cell[6336, 194, 226, 4, 53, "Text",ExpressionUUID->"aa3e97ca-a22d-46a9-b245-6e33ee8f3de7"],
Cell[6565, 200, 379, 8, 30, "Input",ExpressionUUID->"3f8529aa-acdd-4c70-9eda-1f148d89993e"],
Cell[6947, 210, 250, 7, 53, "Text",ExpressionUUID->"ca363aea-bf2b-459c-b6a7-de0925e34b15"],
Cell[7200, 219, 2583, 60, 178, "Input",ExpressionUUID->"7b2b514b-554f-4016-93dd-9a8c101b360b"],
Cell[9786, 281, 265, 6, 53, "Text",ExpressionUUID->"f40ca323-7c2b-4c33-a90f-5a91b9b1a46e"],
Cell[CellGroupData[{
Cell[10076, 291, 530, 14, 30, "Input",ExpressionUUID->"5dfece40-daed-40f0-878b-130253526cc9"],
Cell[10609, 307, 562, 13, 50, "Output",ExpressionUUID->"85465226-cb22-406a-b3a0-2d49e3b28fc6"]
}, Open  ]],
Cell[11186, 323, 215, 6, 53, "Text",ExpressionUUID->"9b8c70d7-bdcb-41e7-acfa-4530768fafbf"],
Cell[11404, 331, 1224, 31, 94, "Input",ExpressionUUID->"aede34f6-e2e7-4de8-9b78-23e915becc21"],
Cell[12631, 364, 428, 10, 99, "Text",ExpressionUUID->"f51beef0-218a-413d-913e-90855c974add"],
Cell[CellGroupData[{
Cell[13084, 378, 732, 18, 52, "Input",ExpressionUUID->"cb2cd810-19ad-4a5e-b5b6-852a00b337f5"],
Cell[13819, 398, 12095, 251, 434, "Output",ExpressionUUID->"a49055ca-3751-4294-9e58-a488f5d23675"]
}, Open  ]]
}
]
*)

